# pytori

**P. Belanger**

A Python package for the transport of loops and tori in accelerator beam-lines.

## Overview  
`pytori` is designed to describe, track and visualize the deformation of 6-dimensional tori for phase-space studies in beam dynamics.  
It can be used for applications in beam optics, linear dynamics, non-linear dynamics and Normal Form analysis. Most classes of the project can be used either in a numerical framework (i.e., based on `numpy`) or a symbolic framework (i.e., based on `sympy`).

More detailed theoretical background and derivations are available in P. Belanger’s Ph.D. thesis.

## Features  
- Support for both numerical (numpy) and symbolic (sympy) workflows  
- Representation of loops and tori in 6D phase-space  
- Tracking of deformations along accelerator beam lines  
- Integration with beam optics / normal-form analysis



## Installation
```bash
pip install pytori
```

## Usage
Examples will be added shortly.


### Basic Torus
